@@ -132,7 +132,7 @@ bitchute.com videos (L<StreamFinder::Bitchute>),
 blogger.com videos (L<StreamFinder::Blogger>), 
 brandnewtube.com and ugetube.com videos (L<StreamFinder::BrandNewTube>), 
 brighteon.com videos (L<StreamFinder::Brighteon>), 
-castbox.fm podcases (L<StreamFinder::Castbox>), 
+castbox.fm podcasts (L<StreamFinder::Castbox>), 
 podcasts.google.com podcasts (L<StreamFinder::Google>), 
 iheartradio.com radio stations and podcasts (L<StreamFinder::IHeartRadio>), 
 www.internetradio.com radio stations (L<StreamFinder::InternetRadio>), 
@@ -254,7 +254,7 @@ I<-hls_bandwidth> => "I<number>"
 
 Limit HLS (m3u8) streams that contain a list of other HLS streams of varying 
 BANDWIDTH values (in BITS per second) by selecting the highest bitrate stream 
-at or below the specified limit when I<$stream->getURL()> is called.
+at or below the specified limit when I<$stream>->I<getURL()> is called.
 
 DEFAULT I<-none-> (no limiting by bitrate).
 
@@ -504,7 +504,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 our $DEBUG = 0;
 
 require Exporter;
