@@ -226,7 +226,7 @@ sub getURL   #LIKE GET, BUT ONLY RETURN THE SINGLE ONE W/BEST BANDWIDTH AND RELI
 		}
 	}
 
-	print STDERR "-getURL returning stream=$firstStream=\n";
+	print STDERR "-getURL returning stream=$firstStream=\n"  if ($DEBUG);
 	return $firstStream;
 }
 
